# pyamr

<img src="docs/source/_static/images/logo-pyamr-v1.png" align="right" width="130">

[url-py39]: https://www.python.org/downloads/release/python-390/
[url-license]: https://www.gnu.org/licenses/gpl-3.0
[url-codecov]: https://codecov.io/gh/bahp/pyAMR
[url-readthedocs]: https://readthedocs.org/projects/docs/badge/?version=latest
[url-gh-package]: https://github.com/bahp/pyAMR/actions/workflows/python-package.yml

[badge-py39]: https://img.shields.io/badge/python-3.9-blue.svg
[badge-codecov]: https://codecov.io/gh/bahp/pyAMR/branch/main/graph/badge.svg?token=GLL7GYY5TE
[badge-license]: https://img.shields.io/badge/license-GPLv3-orange.svg
[badge-gh-package]: https://github.com/bahp/pyAMR/actions/workflows/python-package.yml/badge.svg

[![Python 3.6][badge-py39]][url-py39]
[![readthedocs][url-readthedocs]]()
[![codecov][badge-codecov]][url-codecov]
[![License][badge-license]][url-license]

[![.github/workflows/python-package.yml][badge-gh-package]][url-gh-package]

[url-documentation]: https://bahp.github.io/pyAMR/index.html
[url-installation]: https://bahp.github.io/pyAMR/usage/installation.html
[url-development]: https://bahp.github.io/pyAMR/usage/development.html

Community | [Documentation][url-documentation] | Resources | Contributors | Release Notes

PyAMR is a python lightweight library to facilitate the computation of common Antimicrobial 
Resistance (AMR) related statistics such as the proportion of resistance isolates, the 
resistance trend or the antimicrobial spectrum of activity. In addition, it includes a number 
of examples to visualise such information which relay on plotting libraries such as 
``matplotlib``, ``seaborn`` or ``plotly``.



<!-- ----------------------- -->
<!--    ABOUT THE PROJECT    -->
<!-- ----------------------- -->
## About the project

**EPIC IMPOC** is an NIHR i4i funded project which aims to develop an intelligent clinical 
decision support system to help doctors prescribe the most appropriate antibiotics. 
EPIC IMPOC is a collaborative project between medics and other health-care professionals from 
the National Institute for Health Research Health Protection Research Unit (NIHR HPRU) and 
engineers from the Centre for Bio-Inspire Technology (CBIT) at Imperial College London.

When using any of this project's source code, please cite:

```console
@article{hernandez2021resistance,
  title = {Resistance Trend Estimation Using Regression Analysis to Enhance Antimicrobial Surveillance: A Multi-Centre Study in London 2009--2016},
  author = {Hernandez, Bernard and Herrero-Vi{\~n}as, Pau and Rawson, Timothy M and Moore, Luke SP and Holmes, Alison H and Georgiou, Pantelis},
  journal = {Antibiotics},
  volume = {10},
  number = {10},
  pages = {1267},
  year = {2021},
  month = oct,
  publisher = {MDPI},
  doi = {10.3390/antibiotics10101267},
  url = {},
}
```


<!-- ----------------------- -->
<!--     Installation        -->
<!-- ----------------------- -->
## Installation

Please follow the [Installation Guide][url-installation].

## License
## Changelog
## Roadmap
## Acknowledgements
## Contributors
## Support
## FAQ
## Contact

$ python -m build --sdist --wheel